@@ -1,6 +1,6 @@
 package String::Charcount;
 
-$VERSION = '0.08';
+$VERSION = '0.09';
 @subs = qw(count count_unique percentage);
 @EXPORT_OK = @subs;
 %EXPORT_TAGS = (all => [ @subs ]);
@@ -19,10 +19,10 @@ String::Charcount - Count the occurence of characters within a string
 
  $string = 'The lazy brown fox jumped over the cat sitting on the fence.';
 
- $count = count($string);
+ $count = count( $string );
  print 'e exists ', $count->{e}, ' times',"\n";
 
- $percentage = percentage($string, $count);
+ $percentage = percentage( $string, $count );
  print 'e percentage - ', $percentage->{e}, '%',"\n";
 
 =head1 DESCRIPTION
@@ -36,7 +36,7 @@ calculates percentage of occurence.
 
 Counts the occurence of all characters within a string.
 
- $count = count($string);
+ $count = count( $string );
  print 'e exists ', $count->{e}, ' times',"\n";
 
 Returns an hashref with characters as keys and 
@@ -45,13 +45,14 @@ occurences as values.
 =cut
 
 sub count {
-    my($string) = @_;
-    croak 'usage: count($string)' unless $string;      
+    my ($string) = @_;
+    croak 'usage: count( $string )' unless $string;      
          
-    my %count;
+    my %count; 
     for my $char (split '', $string) { 
         $count{$char}++; 
     }
+    
     return \%count;
 }
 
@@ -59,20 +60,21 @@ sub count {
 
 Counts unique characters (case-sensitive) within a string.
 
- $unique = count_unique($string);
+ $unique = count_unique( $string );
  
 Returns a string.
 
 =cut
 
 sub count_unique {
-    my($string) = @_;
-    croak 'usage: count_unique($string)' unless $string;       
+    my ($string) = @_;
+    croak 'usage: count_unique( $string )' unless $string;       
       
     my %count;
-    for my $i (0..(length($string) - 1)) {
-        $count{substr $string, $i, 1}++;
+    for my $i (0 .. (length( $string ) - 1)) {
+        $count{substr( $string, $i, 1 )}++;
     } 
+    
     return scalar keys %count;
 }
 
@@ -81,7 +83,7 @@ sub count_unique {
 Calculates percentage of occurence of 
 all characters within a string.
 
- $percentage = percentage($string, [$count]);
+ $percentage = percentage( $string, [$count] );
  print 'e percentage - ', $percentage->{e}, '%',"\n";
 
 Returns an hashref with characters as keys and 
@@ -91,15 +93,17 @@ percentages of occurence as values.
 
 sub percentage {
     my $string = shift;
-    my %count  = %{'shift'} || %{count($string)}; 
-    croak 'usage: percentage($string, [$countref])' unless $string;          
+    my %count  = %{'shift'} || %{count( $string )}; 
+    croak 'usage: percentage( $string, [$countref] )' unless $string;          
       
     my $perc_single = 100 / length $string;
          
     my %percentage;
+    
     for my $char (keys %count) {
         $percentage{$char} = sprintf "%2.2f", $count{$char} * $perc_single;
-    }         
+    }
+             
     return \%percentage;
 }
 
